@@ -6,7 +6,7 @@
  * Felix Wolfsteller <felix.wolfsteller@intevation.de>
  *
  * Copyright:
- * Copyright (C) 2008 Intevation GmbH
+ * Copyright (C) 2009 Greenbone Networks GmbH
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -21,16 +21,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * In addition, as a special exception, you have
- * permission to link the code of this program with the OpenSSL
- * library (or with modified versions of OpenSSL that use the same
- * license as OpenSSL), and distribute linked combinations including
- * the two. You must obey the GNU General Public License in all
- * respects for all of the code used other than OpenSSL. If you
- * modify this file, you may extend this exception to your version
- * of the file, but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version.
  */
 
 /**
@@ -44,15 +34,17 @@
 #include <gtk/gtk.h>
 #include "glib.h"
 
+#include <openvas/system.h> /* for efree, estrdup */
+
 #include "nvt_pref_sshlogin.h"
 
-#include "arglists.c"
+#include "arglists.h"
 #include "context.h"
 #include "comm.h" // for PREF_SSH_CREDENTIALS only
 #include "error_dlg.h"
 #include "hash_table_file.h"
-#include "nessus_i18n.h"
-#include "nessus_plugin.h"
+#include "openvas_i18n.h"
+#include "openvas_plugin.h"
 #include "read_target_file.h"
 #include "ssh_key_info_form.h"
 #include "ssh_keys_dialog.h"
@@ -419,7 +411,7 @@ nvt_pref_sshlogin_rebuild_all (struct context* ctx)
 }
 
 /**
- * @brief Rebuilds the GUI of the context ctx or sets it up of if it does
+ * @brief Rebuilds the GUI of the context ctx or sets it up if it does
  * @brief not exist yet.
  * 
  * Rebuilds the table with hostnames and sshlogin- comboboxes and selects the
