@@ -21,16 +21,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * In addition, as a special exception, you have
- * permission to link the code of this program with the OpenSSL
- * library (or with modified versions of OpenSSL that use the same
- * license as OpenSSL), and distribute linked combinations including
- * the two. You must obey the GNU General Public License in all
- * respects for all of the code used other than OpenSSL. If you
- * modify this file, you may extend this exception to your version
- * of the file, but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version.
  */
 
 #include <unistd.h>
@@ -39,12 +29,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "nessus_i18n.h"
+#include "openvas_i18n.h"
 
 /** @TODO Replace by openvas error showing methods (src/gui/err_dlg.c). */
 static void ERROR(gchar *str)
 {
-  GtkWidget*m=gtk_message_dialog_new(GTK_WINDOW(NULL), GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, str);
+  GtkWidget*m=gtk_message_dialog_new(GTK_WINDOW(NULL), GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", str);
   gtk_dialog_run(GTK_DIALOG(m));
   gtk_object_destroy(GTK_OBJECT(m));
 }
