@@ -6,7 +6,7 @@
  * Felix Wolfsteller <felix.wolfsteller@intevation.de>
  *
  * Copyright:
- * Copyright (C) 2008 Intevation GmbH
+ * Copyright (C) 2009 Greenbone Networks GmbH
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -21,20 +21,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * In addition, as a special exception, you have
- * permission to link the code of this program with the OpenSSL
- * library (or with modified versions of OpenSSL that use the same
- * license as OpenSSL), and distribute linked combinations including
- * the two. You must obey the GNU General Public License in all
- * respects for all of the code used other than OpenSSL. If you
- * modify this file, you may extend this exception to your version
- * of the file, but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version.
  */
 
 #include <includes.h>
-#include "nessus_i18n.h"
+#include "openvas_i18n.h"
 
 #ifdef USE_GTK
 #include <gtk/gtk.h>
@@ -148,7 +138,7 @@ name_typed_in_cb(GtkEntry *entry, ssh_key_info_form* form)
 {
   const char* name    = gtk_entry_get_text(entry);
 
-  char* home          = prefs_get_nessushome();
+  char* home          = prefs_get_openvashome();
 
   gchar* canoname     = g_strdup (name);
 
