@@ -6,7 +6,7 @@
  * Felix Wolfsteller <felix.wolfsteller@intevation.de>
  *
  * Copyright:
- * Copyright (C) 2008 Intevation GmbH
+ * Copyright (C) 2009 Greenbone Networks GmbH
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -21,20 +21,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * In addition, as a special exception, you have
- * permission to link the code of this program with the OpenSSL
- * library (or with modified versions of OpenSSL that use the same
- * license as OpenSSL), and distribute linked combinations including
- * the two. You must obey the GNU General Public License in all
- * respects for all of the code used other than OpenSSL. If you
- * modify this file, you may extend this exception to your version
- * of the file, but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version.
  */
 
 #include <includes.h>
-#include "nessus_i18n.h"
+#include "openvas_i18n.h"
 
 #ifdef USE_GTK
 #include <gtk/gtk.h>
@@ -59,11 +49,12 @@
  * ssh logins.
  */
 
+
 /**
  * @brief Callback function to open the OpenVAS SSH Key Manager.
- * 
+ *
  * Only calls ssh_keys_dialog_show.
- * 
+ *
  * @see ssh_keys_dialog_show
  */
 void
@@ -73,9 +64,10 @@ ssh_manager_button_cb (GtkWidget* super, void* ignored)
   ssh_keys_dialog_show();
 }
 
+
 /**
  * @brief Does not _empty_ the notebook but displays a placeholder (~"No logins yet").
- * 
+ *
  * @param listnotebook Listnotebook to add the 'empty' to.
  */
 static void
@@ -89,8 +81,9 @@ ssh_keys_dialog_empty (GtkWidget* listnotebook)
 
 
 /**
- * Creates a ssh_key_info_form from an openvas_ssh_login and adds it as a page to
- * a Listnotebook.
+ * @brief Creates a ssh_key_info_form from an openvas_ssh_login and adds it as
+ * @brief a page to a Listnotebook.
+ *
  * @param _ignored --ignored-- (might be non-NULL if used as callback).
  * @param login Login to create a form from.
  * @param listnotebook Listnotebook to add the page to.
@@ -115,11 +108,12 @@ ssh_keys_dialog_add_key (char* _ignored, openvas_ssh_login* login,
   listnotebook_select_page_named (listnotebook, login->name);
 }
 
+
 /**
  * @brief Callback for click on 'delete'.
- * 
+ *
  * Asks the user if he is sure that the selected login should be deleted.
- * 
+ *
  * @param parent   ignored (callback).
  * @param notebook Callback user-data: the listnotebook in which a login is
  *                 selected.
@@ -169,7 +163,7 @@ ssh_keys_dialog_delete_login (GtkWidget* parent, GtkWidget* notebook)
 
       // Save the file so that the removed login is not listed anymore and will
       // not appear next time.
-      char* loginsfile = g_build_filename(prefs_get_nessushome(), ".openvas", ".ssh", ".logins", NULL);
+      char* loginsfile = g_build_filename(prefs_get_openvashome(), ".openvas", ".ssh", ".logins", NULL);
       openvas_ssh_login_file_write(Global->sshkeys, loginsfile);
       efree(&loginsfile);
       listnotebook_remove_page (notebook, selected_account);
@@ -182,6 +176,9 @@ ssh_keys_dialog_delete_login (GtkWidget* parent, GtkWidget* notebook)
 
       // Rebuild the GUIS in scopes
       nvt_pref_sshlogin_rebuild_all (Global);
+#ifdef USE_OMP
+      nvt_pref_sshlogin_rebuild_all (Servers);
+#endif
     }
   // else: Do nothing, user does not want to delete that account.
 }
@@ -189,12 +186,12 @@ ssh_keys_dialog_delete_login (GtkWidget* parent, GtkWidget* notebook)
 
 /**
  * @brief Prompts the user for information about a new ssh login.
- * 
+ *
  * (Shows a dialog with an editable ssh_key_info_form).
  * The listnotebook parameter is passed on to the dialog.
  * If creation of a ssh keypair was successfull, information about the
  * openvas_ssh_login will be added to the notebook.
- * 
+ *
  * @param parent --ignored-- (might be non-NULL if used as callback).
  * @param notebook Listnotebook to add a page to if ssh keypair generation was
  *                 successfull.
@@ -233,7 +230,7 @@ ssh_keys_dialog_prompt_new (GtkWidget* parent, GtkWidget* notebook)
       {
       // Check entries
       openvas_ssh_login* loginfo = ssh_key_info_form_produce_login(form);
-      if (openvas_ssh_key_create(loginfo) == FALSE)
+      if (openvas_ssh_key_create (loginfo) == FALSE)
         {
           show_error(_("Error creating key files."));
           break;
@@ -242,9 +239,9 @@ ssh_keys_dialog_prompt_new (GtkWidget* parent, GtkWidget* notebook)
       if (Global->sshkeys == NULL)
         Global->sshkeys = g_hash_table_new_full(g_str_hash, g_str_equal, NULL,
                                      (GDestroyNotify) openvas_ssh_login_free);
-      g_hash_table_insert (Global->sshkeys, loginfo->name, loginfo); 
+      g_hash_table_insert (Global->sshkeys, loginfo->name, loginfo);
 
-      gchar* loginsfile = g_build_filename (prefs_get_nessushome(), ".openvas", ".ssh", ".logins", NULL);
+      gchar* loginsfile = g_build_filename (prefs_get_openvashome(), ".openvas", ".ssh", ".logins", NULL);
       openvas_ssh_login_file_write (Global->sshkeys, loginsfile);
       g_free (loginsfile);
 
@@ -271,6 +268,9 @@ ssh_keys_dialog_prompt_new (GtkWidget* parent, GtkWidget* notebook)
 
       ssh_keys_dialog_add_key (NULL, loginfo, notebook);
       nvt_pref_sshlogin_update_all_comboboxes (Global, loginfo->name);
+#ifdef USE_OMP
+      nvt_pref_sshlogin_update_all_comboboxes (Servers, loginfo->name);
+#endif
       break;
       }
     default:
