@@ -7,7 +7,7 @@
  * Felix Wolfsteller <felix.wolfsteller@intevation.de>
  *
  * Copyright:
- * Copyright (C) 2008 Intevation GmbH
+ * Copyright (C) 2009 Greenbone Networks GmbH
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2,
@@ -22,26 +22,27 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
- *
- * In addition, as a special exception, you have
- * permission to link the code of this program with the OpenSSL
- * library (or with modified versions of OpenSSL that use the same
- * license as OpenSSL), and distribute linked combinations including
- * the two. You must obey the GNU General Public License in all
- * respects for all of the code used other than OpenSSL. If you
- * modify this file, you may extend this exception to your version
- * of the file, but you are not obligated to do so. If you do not
- * wish to do so, delete this exception statement from your version.
  */
 
+#include <glib/gstdio.h>
+
+#include <stdio.h> /* for remove */
+#include <unistd.h> /* for unlink */
+
+#include "system.h" /* for efree */
+
 #include "openvas_ssh_login.h"
 #include "openvas_ssh_key_create.h"
 #include "file_utils.h"
-#include "nessus_i18n.h"
+#include "openvas_i18n.h"
 #include "error_dlg.h"
-#include <glib/gstdio.h>
+
+/** @todo Remove dependence of config.h (some defines influence member variables
+ *        of struct context in context.h) */
+#include "config.h" /* to have ENABLE_SAVE_TESTS defined before including the
+                          context */
 #include "context.h"
-#include "includes.h" // For stdio (function: remove)
+
 
 /**
  * @brief Creates a private key for local checks.
@@ -210,7 +211,7 @@ gboolean openvas_ssh_pubkey_create (const char* comment, char* passphrase,
 
 /**
  * @brief Creates the public and private key files.
- * 
+ *
  * @param loginfo.
  * @return TRUE if things went good, FALSE if things went bad.
  */
